package net.pleus.services.calculator.restclient;

import javax.ws.rs.WebApplicationException;
import javax.ws.rs.client.Client;
import javax.ws.rs.client.ClientBuilder;
import javax.ws.rs.client.Entity;
import javax.ws.rs.client.ResponseProcessingException;
import javax.ws.rs.core.MediaType;

import net.pleus.services.calculator.api.Calculator;
import net.pleus.services.calculator.api.CalculatorException;
import net.pleus.services.calculator.api.model.PerformCalculationsRequest;
import net.pleus.services.calculator.api.model.PerformCalculationsResponse;

/**
 * Client for the service Calculator
 * @author  Wolfgang Pleus
 *
 */
public class CalculatorClient implements Calculator {

	private static final String ENDPOINT= "/services/calculator/rest/api";
	
	private String server = null;
	private int port = 0;
	private String mediaType = MediaType.APPLICATION_JSON;
	
	public CalculatorClient(String server, int port){
		this.server = server;
		this.port = port;
	}
	
	public void setMediaType(String mediaType){
		this.mediaType = mediaType;
	}

	@Override
	public PerformCalculationsResponse performCalculations(PerformCalculationsRequest request) throws CalculatorException {
	 
		Client client = ClientBuilder.newClient();
		 
		client.register(ServiceExceptionFilter.class);
		try{
			PerformCalculationsResponse response = client.target(buildUrl("/performcalculations"))
			        .request(mediaType)
			        .post(Entity.json(request),PerformCalculationsResponse.class);
	     
			return response;
		}
		catch(Throwable e){
			throw mapException(e);
		}
	}
	
	/**
	 * Helper to convert arbitrary exceptions to service exceptions  
	 * @param e Throwable
	 * @return Service Exception
	 */
	private CalculatorException mapException(Throwable e){
		CalculatorException ret =  new CalculatorException(e);
		if(e instanceof ResponseProcessingException){
			
			Throwable cause = e.getCause().getCause();
			if(cause instanceof CalculatorException){
				ret = (CalculatorException) cause;
			}
			else{
				ret = new CalculatorException(cause);
			}
			
		}
		return ret;
		
	}
	/**
	 * Helper to build full server urls
	 * @param operation operation to call
	 * @return url
	 * @throws CalculatorException
	 */
	private String buildUrl(String operation) throws CalculatorException{

		if(server == null || port == 0){
			throw new CalculatorException("Server and port must be set.");
		}

		return "http://" + server + ":" + port + ENDPOINT + operation;
	}

}
