package net.pleus.services.calculator.binding.jsonhttp;

import static org.hamcrest.Matchers.equalTo;
import static org.junit.Assert.assertThat;

import java.net.URL;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.test.IntegrationTest;
import org.springframework.boot.test.SpringApplicationConfiguration;
import org.springframework.boot.test.TestRestTemplate;
import org.springframework.http.ResponseEntity;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
import org.springframework.test.context.web.WebAppConfiguration;
import org.springframework.web.client.RestTemplate;

import junit.framework.Assert;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

import net.pleus.services.calculator.api.model.ArrayOfCalculation;
import net.pleus.services.calculator.api.model.Calculation;
import net.pleus.services.calculator.api.model.PerformCalculationsRequest;
import net.pleus.services.calculator.api.model.PerformCalculationsResponse;
import net.pleus.services.calculator.api.model.Operation;
import net.pleus.services.calculator.api.model.ArrayOfInt;
import net.pleus.services.calculator.api.CalculatorException;
import net.pleus.services.calculator.restclient.CalculatorClient;

@RunWith(SpringJUnit4ClassRunner.class)
@SpringApplicationConfiguration(classes = Application.class)
@WebAppConfiguration
@IntegrationTest({"server.port=0"})
public class CalculatorTest {

    @Value("${local.server.port}")
    private int port;

    private CalculatorClient client;

	@Before
	public void setUp() throws Exception {
        client = new CalculatorClient("localhost",port);
	}
    
	@Test
	public void add() throws Exception {

		// Create calculation inputs
		 Calculation calculation = new Calculation()
			 .withOperation(Operation.DIVIDE)
			 .withInputs(new ArrayOfInt()
			 	.withValue(9,3,2)
			 );
				 
		// Create request
		PerformCalculationsRequest request = new PerformCalculationsRequest()
		    .withCorrelationid(UUID.randomUUID().toString())
		    .withCalculations(new ArrayOfCalculation().withValue(calculation));
		
        // Call service	
		PerformCalculationsResponse response = client.performCalculations(request);

	    // Check correlation
		Assert.assertEquals(request.getCorrelationid(), response.getCorrelationid());
		
        // Check result
		Assert.assertEquals(new BigDecimal(1.5), response.getCalculations().getValue().get(0).getResult());	
     }
    
}