package net.pleus.services.calculator;
 
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

import javax.inject.Named;

import net.pleus.services.calculator.api.Calculator;
import net.pleus.services.calculator.api.CalculatorException;
import net.pleus.services.calculator.api.model.ArrayOfCalculationResult;
import net.pleus.services.calculator.api.model.Calculation;
import net.pleus.services.calculator.api.model.CalculationResult;
import net.pleus.services.calculator.api.model.Operation;
import net.pleus.services.calculator.api.model.PerformCalculationsRequest;
import net.pleus.services.calculator.api.model.PerformCalculationsResponse;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Service Implementierung
 * @author Wolfgang Pleus
 */
@Named("service")
public class CalculatorImpl implements Calculator{

	private static final Logger log = LoggerFactory.getLogger(CalculatorImpl.class);
	 
	//private UserDAO userDAO = null;
	
	public CalculatorImpl() {}
	
//	@Inject
//	public CalculatorImpl(UserDAO userDAO) {
//		this.userDAO = userDAO;
//	}

	@Override
	public PerformCalculationsResponse performCalculations(PerformCalculationsRequest request) throws CalculatorException {
		log.debug("Calculator.performCalcuations (start):" + request);
	    
		List<CalculationResult> results = new ArrayList<>();

		try {
		
			// Perform all calculations
			for (Calculation calculation:request.getCalculations().getValue()){
				results.add(performCalculation(calculation));
			}
			
			// Create response
			PerformCalculationsResponse response = new PerformCalculationsResponse()
			.withCorrelationid(request.getCorrelationid())
			.withCalculations(new ArrayOfCalculationResult()
			  .withValue(results)
			);

			log.debug("Calculator.performCalculations (end):" + response);
			
			return response;
		}
		catch(Throwable e){
			throw new CalculatorException(e.getMessage(),CalculatorException.ERROR_DIVISIONBYZERO,e);
		}
	}
	
	/**
	 * Performs a single calculation
	 * @param calculation
	 * @return result
	 */
	private CalculationResult performCalculation(Calculation calculation){
		
		BigDecimal value = new BigDecimal(0);

		Operation operation = calculation.getOperation();
		List<Integer> values = calculation.getInputs().getValue();

		switch(operation){
			case ADD:
				value = add(values);
				break;
			case SUBTRACT:
				value = substract(values);
				break;
			case DIVIDE:
				value = divide(values);
				break;
			case MULTIPLY:
				value = multiply(values);
				break;
		}
		
		
		CalculationResult result = new CalculationResult()
			.withResult(value);

		return result;
	}
	
	private BigDecimal multiply(List<Integer> values) {
		double result = 1;
		for(Integer value:values){
			result *= value;
		}
		return new BigDecimal(result);
	}

	private BigDecimal divide(List<Integer> values) {
		double result = values.get(0);
		for(Integer value:values.subList(1, values.size())){
			result /= value;
		}
		return new BigDecimal(result);
	}

	private BigDecimal substract(List<Integer> values) {
		double result = values.get(0);
		for(Integer value:values.subList(1, values.size())){
			result -= value;
		}
		return new BigDecimal(result);
	}

	private BigDecimal add(List<Integer> values) {
		double result = 0;
		for(Integer value:values){
			result += value;
		}
		return new BigDecimal(result);
	}
}

